import React from "react";
import { UserAPI } from "../API/API";
import { useQuery } from "@tanstack/react-query";
import { CircularProgress } from "@mui/material";
import styles from "../../styles";

type props = {
  allow_only: "Student" | "Teacher" | "Technician";
  children: React.ReactNode;
};
export default function RestrictedComponent(props: props) {
  const user = useQuery({ queryKey: ["user"], queryFn: UserAPI });
  if (user.isLoading) {
    return (
      <>
        <CircularProgress style={{ height: "128px", width: "128px" }} />
        <p
          style={{
            ...styles.text_dark,
            ...styles.text_L,
          }}
        >
          Loading
        </p>
      </>
    );
  }
  if (props.allow_only === "Teacher") {
    if (user.data && user.data.is_teacher) {
      return <>{props.children}</>;
    }
  } else if (props.allow_only === "Technician") {
    if (user.data && user.data.is_technician) {
      return <>{props.children}</>;
    }
  } else if (props.allow_only === "Student") {
    if (user.data && !user.data.is_technician && !user.data.is_teacher) {
      return <>{props.children}</>;
    }
  }
  return <></>;
}
